@@ -15,8 +15,9 @@ import (
 	"github.com/sirupsen/logrus"
 
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
-	"github.com/batchcorp/plumber/config"
-	"github.com/batchcorp/plumber/server/types"
+
+	"github.com/streamdal/plumber/config"
+	"github.com/streamdal/plumber/server/types"
 )
 
 type Actions struct {
