@@ -3,7 +3,7 @@ package awssns
 import (
 	"context"
 
-	"github.com/batchcorp/plumber/types"
+	"github.com/streamdal/plumber/types"
 
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/records"
