@@ -9,8 +9,8 @@ import (
 	"github.com/aws/aws-sdk-go/service/sns"
 	"github.com/pkg/errors"
 
-	"github.com/batchcorp/plumber/tunnel"
-	"github.com/batchcorp/plumber/validate"
+	"github.com/streamdal/plumber/tunnel"
+	"github.com/streamdal/plumber/validate"
 
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/records"
