@@ -5,29 +5,29 @@ import (
 
 	"github.com/pkg/errors"
 
-	"github.com/batchcorp/plumber/backends/activemq"
-	"github.com/batchcorp/plumber/backends/awskinesis"
-	"github.com/batchcorp/plumber/backends/awssns"
-	"github.com/batchcorp/plumber/backends/awssqs"
-	azureEventhub "github.com/batchcorp/plumber/backends/azure-eventhub"
-	azureServicebus "github.com/batchcorp/plumber/backends/azure-servicebus"
-	"github.com/batchcorp/plumber/backends/cdcmongo"
-	"github.com/batchcorp/plumber/backends/cdcpostgres"
-	"github.com/batchcorp/plumber/backends/gcppubsub"
-	"github.com/batchcorp/plumber/backends/kafka"
-	kubemqQueue "github.com/batchcorp/plumber/backends/kubemq-queue"
-	"github.com/batchcorp/plumber/backends/memphis"
-	"github.com/batchcorp/plumber/backends/mqtt"
-	"github.com/batchcorp/plumber/backends/nats"
-	natsJetstream "github.com/batchcorp/plumber/backends/nats-jetstream"
-	natsStreaming "github.com/batchcorp/plumber/backends/nats-streaming"
-	"github.com/batchcorp/plumber/backends/nsq"
-	"github.com/batchcorp/plumber/backends/pulsar"
-	rabbitStreams "github.com/batchcorp/plumber/backends/rabbit-streams"
-	"github.com/batchcorp/plumber/backends/rabbitmq"
-	"github.com/batchcorp/plumber/backends/rpubsub"
-	"github.com/batchcorp/plumber/backends/rstreams"
-	"github.com/batchcorp/plumber/tunnel"
+	"github.com/streamdal/plumber/backends/activemq"
+	"github.com/streamdal/plumber/backends/awskinesis"
+	"github.com/streamdal/plumber/backends/awssns"
+	"github.com/streamdal/plumber/backends/awssqs"
+	azureEventhub "github.com/streamdal/plumber/backends/azure-eventhub"
+	azureServicebus "github.com/streamdal/plumber/backends/azure-servicebus"
+	"github.com/streamdal/plumber/backends/cdcmongo"
+	"github.com/streamdal/plumber/backends/cdcpostgres"
+	"github.com/streamdal/plumber/backends/gcppubsub"
+	"github.com/streamdal/plumber/backends/kafka"
+	kubemqQueue "github.com/streamdal/plumber/backends/kubemq-queue"
+	"github.com/streamdal/plumber/backends/memphis"
+	"github.com/streamdal/plumber/backends/mqtt"
+	"github.com/streamdal/plumber/backends/nats"
+	natsJetstream "github.com/streamdal/plumber/backends/nats-jetstream"
+	natsStreaming "github.com/streamdal/plumber/backends/nats-streaming"
+	"github.com/streamdal/plumber/backends/nsq"
+	"github.com/streamdal/plumber/backends/pulsar"
+	rabbitStreams "github.com/streamdal/plumber/backends/rabbit-streams"
+	"github.com/streamdal/plumber/backends/rabbitmq"
+	"github.com/streamdal/plumber/backends/rpubsub"
+	"github.com/streamdal/plumber/backends/rstreams"
+	"github.com/streamdal/plumber/tunnel"
 
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/records"
