@@ -15,9 +15,9 @@ import (
 	"github.com/batchcorp/plumber-schemas/build/go/protos/args"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 
-	"github.com/batchcorp/plumber/backends/cdcpostgres/types"
-	plumberTypes "github.com/batchcorp/plumber/types"
-	"github.com/batchcorp/plumber/validate"
+	"github.com/streamdal/plumber/backends/cdcpostgres/types"
+	plumberTypes "github.com/streamdal/plumber/types"
+	"github.com/streamdal/plumber/validate"
 )
 
 const BackendName = "cdc-postgres"
