@@ -14,7 +14,7 @@ import (
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/records"
 
-	"github.com/batchcorp/plumber/backends/cdcpostgres/types"
+	"github.com/streamdal/plumber/backends/cdcpostgres/types"
 )
 
 func (c *CDCPostgres) Read(ctx context.Context, readOpts *opts.ReadOptions, resultsChan chan *records.ReadRecord, errorChan chan *records.ErrorRecord) error {
