@@ -11,9 +11,9 @@ import (
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/records"
 
-	"github.com/batchcorp/plumber/backends/cdcpostgres/types"
-	"github.com/batchcorp/plumber/prometheus"
-	"github.com/batchcorp/plumber/validate"
+	"github.com/streamdal/plumber/backends/cdcpostgres/types"
+	"github.com/streamdal/plumber/prometheus"
+	"github.com/streamdal/plumber/validate"
 )
 
 func (c *CDCPostgres) Relay(ctx context.Context, relayOpts *opts.RelayOptions, relayCh chan interface{}, errorCh chan<- *records.ErrorRecord) error {
