@@ -13,8 +13,9 @@ import (
 	"github.com/batchcorp/plumber-schemas/build/go/protos/encoding"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/records"
-	"github.com/batchcorp/plumber/backends/nats-streaming/stanfakes"
-	"github.com/batchcorp/plumber/validate"
+
+	"github.com/streamdal/plumber/backends/nats-streaming/stanfakes"
+	"github.com/streamdal/plumber/validate"
 )
 
 var _ = Describe("Nats Streaming Backend", func() {
