@@ -7,7 +7,7 @@ import (
 	"github.com/nsqio/go-nsq"
 	"github.com/pkg/errors"
 
-	"github.com/batchcorp/plumber/util"
+	"github.com/streamdal/plumber/util"
 
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/records"
