@@ -11,9 +11,10 @@ import (
 
 	"github.com/batchcorp/plumber-schemas/build/go/protos/args"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
-	"github.com/batchcorp/plumber/types"
-	"github.com/batchcorp/plumber/util"
-	"github.com/batchcorp/plumber/validate"
+
+	"github.com/streamdal/plumber/types"
+	"github.com/streamdal/plumber/util"
+	"github.com/streamdal/plumber/validate"
 )
 
 const BackendName = "pulsar"
