@@ -8,8 +8,8 @@ import (
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/records"
 
-	"github.com/batchcorp/plumber/tunnel"
-	"github.com/batchcorp/plumber/validate"
+	"github.com/streamdal/plumber/tunnel"
+	"github.com/streamdal/plumber/validate"
 )
 
 func (r *RabbitMQ) Tunnel(ctx context.Context, opts *opts.TunnelOptions, tunnelSvc tunnel.ITunnel, errorCh chan<- *records.ErrorRecord) error {
