@@ -18,7 +18,6 @@ import (
 	"fmt"
 	"io/ioutil"
 	"math/rand"
-	"os"
 	"os/exec"
 	"runtime"
 	"time"
@@ -2225,557 +2224,6 @@ var _ = Describe("Functional", func() {
 		})
 	})
 
-	Describe("manage subcommand", func() {
-		Describe("kafka", func() {
-			Describe("relay", func() {
-				var connId string
-				var relayId string
-
-				It("create should work", func() {
-					connId = createKafkaConnection(binary)
-					type createRelayResp struct {
-						RelayId string `json:"relayId"`
-						Status  struct {
-							Message   string `json:"message"`
-							RequestId string `json:"requestId"`
-						} `json:"status"`
-					}
-					testCollectionToken := os.Getenv("TEST_COLLECTION_TOKEN")
-					if testCollectionToken == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token")
-					}
-
-					createRelayCmd := exec.Command(
-						binary,
-						"manage",
-						"create",
-						"relay",
-						"kafka",
-						"--manage-token", "streamdal",
-						"--streamdal-grpc-address", "grpc-collector.streamdal.com:9000",
-						"--connection-id", connId,
-						"--collection-token", testCollectionToken,
-						"--topics", "foo",
-					)
-					out, err := createRelayCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-
-					resp := createRelayResp{}
-					json.Unmarshal(out, &resp)
-					Expect(string(out)).To(ContainSubstring("Relay started"))
-
-					relayId = resp.RelayId
-				})
-
-				It("get should work", func() {
-					if relayId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					type getRelayResp struct {
-						Opts struct {
-							RelayId string `json:"RelayId"`
-						}
-					}
-					getRelayCmd := exec.Command(
-						binary,
-						"manage",
-						"get",
-						"relay",
-						"--manage-token", "streamdal",
-						"--id", relayId,
-					)
-					out, err := getRelayCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					resp := getRelayResp{}
-					json.Unmarshal(out, &resp)
-
-					Expect(resp.Opts.RelayId).To(Equal(relayId))
-				})
-
-				It("stop should work", func() {
-					if relayId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					stopRelayCmd := exec.Command(
-						binary,
-						"manage",
-						"stop",
-						"relay",
-						"--manage-token", "streamdal",
-						"--id", relayId,
-					)
-					out, err := stopRelayCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					Expect(string(out)).To(ContainSubstring("Relay stopped"))
-				})
-
-				It("resume should work", func() {
-					if relayId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					resumeRelayCmd := exec.Command(
-						binary,
-						"manage",
-						"resume",
-						"relay",
-						"--manage-token", "streamdal",
-						"--id", relayId,
-					)
-					out, err := resumeRelayCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					Expect(string(out)).To(ContainSubstring("Relay resumed"))
-				})
-
-				It("delete should work", func() {
-					if relayId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					deleteRelayCmd := exec.Command(
-						binary,
-						"manage",
-						"delete",
-						"relay",
-						"--manage-token", "streamdal",
-						"--id", relayId,
-					)
-					out, err := deleteRelayCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					Expect(string(out)).To(ContainSubstring("Relay deleted"))
-
-					// delete connection
-					deleteConnection(binary, connId)
-				})
-			})
-
-			Describe("tunnel", func() {
-				var connId string
-				var tunnelId string
-
-				It("create should work", func() {
-					connId = createKafkaConnection(binary)
-					type createTunnelResp struct {
-						Status struct {
-							Message   string `json:"message"`
-							RequestId string `json:"requestId"`
-						} `json:"status"`
-						TunnelId string `json:"tunnelId"`
-					}
-
-					batchAPIToken := os.Getenv("TEST_API_TOKEN")
-					if batchAPIToken == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no API token")
-					}
-
-					createTunnelCmd := exec.Command(
-						binary,
-						"manage",
-						"create",
-						"tunnel",
-						"kafka",
-						"--manage-token", "streamdal",
-						"--x-tunnel-address", "dproxy.streamdal.com:443",
-						"--connection-id", connId,
-						"--tunnel-token", batchAPIToken,
-						"--topics", "foo",
-					)
-					out, err := createTunnelCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-
-					resp := createTunnelResp{}
-					json.Unmarshal(out, &resp)
-					Expect(string(out)).To(ContainSubstring("Tunnel created"))
-
-					tunnelId = resp.TunnelId
-				})
-
-				It("get should work", func() {
-					if tunnelId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					type getTunnelResp struct {
-						Opts struct {
-							TunnelId string `json:"TunnelId"`
-						}
-					}
-					getTunnelCmd := exec.Command(
-						binary,
-						"manage",
-						"get",
-						"tunnel",
-						"--manage-token", "streamdal",
-						"--id", tunnelId,
-					)
-					out, err := getTunnelCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					resp := getTunnelResp{}
-					json.Unmarshal(out, &resp)
-
-					Expect(resp.Opts.TunnelId).To(Equal(tunnelId))
-				})
-
-				It("stop should work", func() {
-					if tunnelId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					stopTunnelCmd := exec.Command(
-						binary,
-						"manage",
-						"stop",
-						"tunnel",
-						"--manage-token", "streamdal",
-						"--id", tunnelId,
-					)
-					out, err := stopTunnelCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					Expect(string(out)).To(ContainSubstring("Tunnel replay stopped"))
-				})
-
-				It("resume should work", func() {
-					if tunnelId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					resumeTunnelCmd := exec.Command(
-						binary,
-						"manage",
-						"resume",
-						"tunnel",
-						"--manage-token", "streamdal",
-						"--id", tunnelId,
-					)
-					out, err := resumeTunnelCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					Expect(string(out)).To(ContainSubstring("Tunnel replay resumed"))
-				})
-
-				It("delete should work", func() {
-					if tunnelId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					deleteTunnelCmd := exec.Command(
-						binary,
-						"manage",
-						"delete",
-						"tunnel",
-						"--manage-token", "streamdal",
-						"--id", tunnelId,
-					)
-					out, err := deleteTunnelCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					Expect(string(out)).To(ContainSubstring("Tunnel replay deleted"))
-
-					// delete connection
-					deleteConnection(binary, connId)
-				})
-
-			})
-
-		})
-
-		Describe("rabbit", func() {
-			Describe("relay", func() {
-				var connId string
-				var relayId string
-
-				It("create should work", func() {
-					connId = createRabbitConnection(binary)
-
-					randID := rand.Int()
-					var (
-						exchangeName string = fmt.Sprintf("testex-%d", randID)
-						queueName    string = fmt.Sprintf("testqueue-%d", randID)
-						routingKey   string = fmt.Sprintf("testqueue-%d", randID)
-					)
-					err := createRabbit(exchangeName, queueName, routingKey)
-					Expect(err).ToNot(HaveOccurred())
-
-					type createRelayResp struct {
-						RelayId string `json:"relayId"`
-						Status  struct {
-							Message   string `json:"message"`
-							RequestId string `json:"requestId"`
-						} `json:"status"`
-					}
-					testCollectionToken := os.Getenv("TEST_COLLECTION_TOKEN")
-					if testCollectionToken == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token")
-					}
-
-					createRelayCmd := exec.Command(
-						binary,
-						"manage",
-						"create",
-						"relay",
-						"rabbit",
-						"--manage-token", "streamdal",
-						"--streamdal-grpc-address", "grpc-collector.streamdal.com:9000",
-						"--connection-id", connId,
-						"--collection-token", testCollectionToken,
-						"--exchange-name", exchangeName,
-						"--queue-name", queueName,
-						"--binding-key", routingKey,
-					)
-					out, err := createRelayCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-
-					resp := createRelayResp{}
-					json.Unmarshal(out, &resp)
-					Expect(string(out)).To(ContainSubstring("Relay started"))
-
-					relayId = resp.RelayId
-				})
-
-				It("get should work", func() {
-					if relayId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					type getRelayResp struct {
-						Opts struct {
-							RelayId string `json:"RelayId"`
-						}
-					}
-					getRelayCmd := exec.Command(
-						binary,
-						"manage",
-						"get",
-						"relay",
-						"--manage-token", "streamdal",
-						"--id", relayId,
-					)
-					out, err := getRelayCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					resp := getRelayResp{}
-					json.Unmarshal(out, &resp)
-
-					Expect(resp.Opts.RelayId).To(Equal(relayId))
-				})
-
-				It("stop should work", func() {
-					if relayId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					stopRelayCmd := exec.Command(
-						binary,
-						"manage",
-						"stop",
-						"relay",
-						"--manage-token", "streamdal",
-						"--id", relayId,
-					)
-					out, err := stopRelayCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					Expect(string(out)).To(ContainSubstring("Relay stopped"))
-				})
-
-				It("resume should work", func() {
-					if relayId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					resumeRelayCmd := exec.Command(
-						binary,
-						"manage",
-						"resume",
-						"relay",
-						"--manage-token", "streamdal",
-						"--id", relayId,
-					)
-					out, err := resumeRelayCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					Expect(string(out)).To(ContainSubstring("Relay resumed"))
-				})
-
-				It("delete should work", func() {
-					if relayId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					deleteRelayCmd := exec.Command(
-						binary,
-						"manage",
-						"delete",
-						"relay",
-						"--manage-token", "streamdal",
-						"--id", relayId,
-					)
-					out, err := deleteRelayCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					Expect(string(out)).To(ContainSubstring("Relay deleted"))
-
-					// delete connection
-					deleteConnection(binary, connId)
-				})
-
-			})
-
-			Describe("tunnel", func() {
-				var connId string
-				var tunnelId string
-
-				It("create should work", func() {
-					connId = createRabbitConnection(binary)
-
-					randID := rand.Int()
-					var (
-						exchangeName string = fmt.Sprintf("testex-%d", randID)
-						queueName    string = fmt.Sprintf("testqueue-%d", randID)
-						routingKey   string = fmt.Sprintf("testqueue-%d", randID)
-					)
-					err := createRabbit(exchangeName, queueName, routingKey)
-					Expect(err).ToNot(HaveOccurred())
-
-					type createTunnelResp struct {
-						Status struct {
-							Message   string `json:"message"`
-							RequestId string `json:"requestId"`
-						} `json:"status"`
-						TunnelId string `json:"tunnelId"`
-					}
-					batchAPIToken := os.Getenv("TEST_API_TOKEN")
-					if batchAPIToken == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no API token")
-					}
-
-					createTunnelCmd := exec.Command(
-						binary,
-						"manage",
-						"create",
-						"tunnel",
-						"rabbit",
-						"--manage-token", "streamdal",
-						"--x-tunnel-address", "dproxy.streamdal.com:443",
-						"--connection-id", connId,
-						"--tunnel-token", batchAPIToken,
-						"--exchange-name", exchangeName,
-						"--routing-key", routingKey,
-					)
-					out, err := createTunnelCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-
-					resp := createTunnelResp{}
-					json.Unmarshal(out, &resp)
-					Expect(string(out)).To(ContainSubstring("Tunnel created"))
-
-					tunnelId = resp.TunnelId
-				})
-
-				It("get should work", func() {
-					if tunnelId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					type getTunnelResp struct {
-						Opts struct {
-							TunnelId string `json:"tunnelId"`
-						}
-					}
-					getTunnelCmd := exec.Command(
-						binary,
-						"manage",
-						"get",
-						"tunnel",
-						"--manage-token", "streamdal",
-						"--id", tunnelId,
-					)
-					out, err := getTunnelCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					resp := getTunnelResp{}
-					json.Unmarshal(out, &resp)
-
-					Expect(resp.Opts.TunnelId).To(Equal(tunnelId))
-				})
-
-				It("stop should work", func() {
-					if tunnelId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					stopTunnelCmd := exec.Command(
-						binary,
-						"manage",
-						"stop",
-						"tunnel",
-						"--manage-token", "streamdal",
-						"--id", tunnelId,
-					)
-					out, err := stopTunnelCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					Expect(string(out)).To(ContainSubstring("Tunnel replay stopped"))
-				})
-
-				It("resume should work", func() {
-					if tunnelId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					resumeTunnelCmd := exec.Command(
-						binary,
-						"manage",
-						"resume",
-						"tunnel",
-						"--manage-token", "streamdal",
-						"--id", tunnelId,
-					)
-					out, err := resumeTunnelCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					Expect(string(out)).To(ContainSubstring("Tunnel replay resumed"))
-				})
-
-				It("delete should work", func() {
-					if tunnelId == "" {
-						defer GinkgoRecover()
-						Skip("Cannot test, no collection token in creation")
-					}
-
-					deleteTunnelCmd := exec.Command(
-						binary,
-						"manage",
-						"delete",
-						"tunnel",
-						"--manage-token", "streamdal",
-						"--id", tunnelId,
-					)
-					out, err := deleteTunnelCmd.CombinedOutput()
-					Expect(err).ToNot(HaveOccurred())
-					Expect(string(out)).To(ContainSubstring("Tunnel replay deleted"))
-
-					// delete connection
-					deleteConnection(binary, connId)
-				})
-
-			})
-
-		})
-	})
-
 })
 
 type Kafka struct {
@@ -3012,17 +2460,22 @@ func createRabbitConnection(binary string) string {
 
 func createRabbit(exchangeName, queueName, routingKey string) error {
 	var err error
+
+	// Create exchange
 	cmd := exec.Command("docker", "exec", "rabbitmq", "rabbitmqadmin", "declare", "exchange", "name="+exchangeName, "type=topic")
 	_, err = cmd.CombinedOutput()
 	if err != nil {
 		return err
 	}
 
-	cmd = exec.Command("docker", "exec", "rabbitmq", "rabbitmqadmin", "declare", "queue", "name="+queueName, "durable=false")
+	// Create queue
+	cmd = exec.Command("docker", "exec", "rabbitmq", "rabbitmqadmin", "declare", "queue", "name="+queueName, "durable=false", "auto_delete=true")
 	_, err = cmd.CombinedOutput()
 	if err != nil {
 		return err
 	}
+
+	// Add binding
 	cmd = exec.Command("docker", "exec", "rabbitmq", "rabbitmqadmin", "declare", "binding", "source="+exchangeName, "destination="+queueName, "routing_key="+routingKey)
 	_, err = cmd.CombinedOutput()
 	if err != nil {
@@ -3032,16 +2485,11 @@ func createRabbit(exchangeName, queueName, routingKey string) error {
 }
 
 func deleteRabbit(exchangeName, queueName string) error {
-	var err error
 	cmd := exec.Command("docker", "exec", "rabbitmq", "rabbitmqadmin", "delete", "exchange", "name="+exchangeName)
-	_, err = cmd.CombinedOutput()
-	if err != nil {
-		return err
-	}
-	cmd = exec.Command("docker", "exec", "rabbitmq", "rabbitmqadmin", "delete", "queue", "name="+queueName)
-	_, err = cmd.CombinedOutput()
-	if err != nil {
-		return err
+
+	if _, err := cmd.CombinedOutput(); err != nil {
+		return errors.Wrap(err, "unable to delete exchange")
 	}
+
 	return nil
 }
