@@ -5,25 +5,14 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/mcuadros/go-lookup"
-	"github.com/pkg/errors"
-	"github.com/posthog/posthog-go"
-
 	"github.com/batchcorp/plumber-schemas/build/go/protos"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/common"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
+	"github.com/mcuadros/go-lookup"
+	"github.com/pkg/errors"
 )
 
 func (p *Plumber) HandleGetConnectionCmd(ctx context.Context, client protos.PlumberServerClient) error {
-	p.EnqueueManage(posthog.Capture{
-		Event:      "command_manage",
-		DistinctId: p.PersistentConfig.PlumberID,
-		Properties: map[string]interface{}{
-			"connection_id": p.CLIOptions.Manage.Get.Connection.Id,
-			"method":        "get_connection",
-		},
-	})
-
 	resp, err := client.GetConnection(ctx, &protos.GetConnectionRequest{
 		Auth: &common.Auth{
 			Token: p.CLIOptions.Manage.GlobalOptions.ManageToken,
@@ -44,14 +33,6 @@ func (p *Plumber) HandleGetConnectionCmd(ctx context.Context, client protos.Plum
 }
 
 func (p *Plumber) HandleGetAllConnectionsCmd(ctx context.Context, client protos.PlumberServerClient) error {
-	p.EnqueueManage(posthog.Capture{
-		Event:      "command_manage",
-		DistinctId: p.PersistentConfig.PlumberID,
-		Properties: map[string]interface{}{
-			"method": "get_all_connections",
-		},
-	})
-
 	resp, err := client.GetAllConnections(ctx, &protos.GetAllConnectionsRequest{
 		Auth: &common.Auth{
 			Token: p.CLIOptions.Manage.GlobalOptions.ManageToken,
@@ -71,15 +52,6 @@ func (p *Plumber) HandleGetAllConnectionsCmd(ctx context.Context, client protos.
 }
 
 func (p *Plumber) HandleDeleteConnectionCmd(ctx context.Context, client protos.PlumberServerClient) error {
-	p.EnqueueManage(posthog.Capture{
-		Event:      "command_manage",
-		DistinctId: p.PersistentConfig.PlumberID,
-		Properties: map[string]interface{}{
-			"method":        "delete_connection",
-			"connection_id": p.CLIOptions.Manage.Delete.Connection.Id,
-		},
-	})
-
 	resp, err := client.DeleteConnection(ctx, &protos.DeleteConnectionRequest{
 		Auth: &common.Auth{
 			Token: p.CLIOptions.Manage.GlobalOptions.ManageToken,
@@ -105,15 +77,6 @@ func (p *Plumber) HandleCreateConnectionCmd(ctx context.Context, client protos.P
 		return errors.Wrap(err, "failed to generate connection options")
 	}
 
-	p.EnqueueManage(posthog.Capture{
-		Event:      "command_manage",
-		DistinctId: p.PersistentConfig.PlumberID,
-		Properties: map[string]interface{}{
-			"backend": p.CLIOptions.Global.XBackend,
-			"method":  "create_connection",
-		},
-	})
-
 	resp, err := client.CreateConnection(ctx, &protos.CreateConnectionRequest{
 		Auth: &common.Auth{
 			Token: p.CLIOptions.Manage.GlobalOptions.ManageToken,
