@@ -4,24 +4,13 @@ import (
 	"context"
 	"strings"
 
-	"github.com/pkg/errors"
-	"github.com/posthog/posthog-go"
-
 	"github.com/batchcorp/plumber-schemas/build/go/protos"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/common"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
+	"github.com/pkg/errors"
 )
 
 func (p *Plumber) HandleGetTunnelCmd(ctx context.Context, client protos.PlumberServerClient) error {
-	p.EnqueueManage(posthog.Capture{
-		Event:      "command_manage",
-		DistinctId: p.PersistentConfig.PlumberID,
-		Properties: map[string]interface{}{
-			"tunnel_id": p.CLIOptions.Manage.Get.Tunnel.Id,
-			"method":    "get_tunnel",
-		},
-	})
-
 	resp, err := client.GetTunnel(ctx, &protos.GetTunnelRequest{
 		Auth: &common.Auth{
 			Token: p.CLIOptions.Manage.GlobalOptions.ManageToken,
@@ -42,14 +31,6 @@ func (p *Plumber) HandleGetTunnelCmd(ctx context.Context, client protos.PlumberS
 }
 
 func (p *Plumber) HandleGetAllTunnelsCmd(ctx context.Context, client protos.PlumberServerClient) error {
-	p.EnqueueManage(posthog.Capture{
-		Event:      "command_manage",
-		DistinctId: p.PersistentConfig.PlumberID,
-		Properties: map[string]interface{}{
-			"method": "get_all_tunnels",
-		},
-	})
-
 	resp, err := client.GetAllTunnels(ctx, &protos.GetAllTunnelsRequest{
 		Auth: &common.Auth{
 			Token: p.CLIOptions.Manage.GlobalOptions.ManageToken,
@@ -68,14 +49,6 @@ func (p *Plumber) HandleGetAllTunnelsCmd(ctx context.Context, client protos.Plum
 }
 
 func (p *Plumber) HandleCreateTunnelCmd(ctx context.Context, client protos.PlumberServerClient) error {
-	p.EnqueueManage(posthog.Capture{
-		Event:      "command_manage",
-		DistinctId: p.PersistentConfig.PlumberID,
-		Properties: map[string]interface{}{
-			"method": "create_tunnel",
-		},
-	})
-
 	// Create tunnel options from CLI opts
 	tunnelOpts, err := generateTunnelOptionsForManageCreate(p.CLIOptions)
 	if err != nil {
@@ -100,15 +73,6 @@ func (p *Plumber) HandleCreateTunnelCmd(ctx context.Context, client protos.Plumb
 }
 
 func (p *Plumber) HandleDeleteTunnelCmd(ctx context.Context, client protos.PlumberServerClient) error {
-	p.EnqueueManage(posthog.Capture{
-		Event:      "command_manage",
-		DistinctId: p.PersistentConfig.PlumberID,
-		Properties: map[string]interface{}{
-			"tunnel_id": p.CLIOptions.Manage.Delete.Tunnel.Id,
-			"method":    "delete_tunnel",
-		},
-	})
-
 	resp, err := client.DeleteTunnel(ctx, &protos.DeleteTunnelRequest{
 		Auth: &common.Auth{
 			Token: p.CLIOptions.Manage.GlobalOptions.ManageToken,
@@ -128,15 +92,6 @@ func (p *Plumber) HandleDeleteTunnelCmd(ctx context.Context, client protos.Plumb
 }
 
 func (p *Plumber) HandleStopTunnelCmd(ctx context.Context, client protos.PlumberServerClient) error {
-	p.EnqueueManage(posthog.Capture{
-		Event:      "command_manage",
-		DistinctId: p.PersistentConfig.PlumberID,
-		Properties: map[string]interface{}{
-			"tunnel_id": p.CLIOptions.Manage.Stop.Tunnel.Id,
-			"method":    "stop_tunnel",
-		},
-	})
-
 	resp, err := client.StopTunnel(ctx, &protos.StopTunnelRequest{
 		Auth: &common.Auth{
 			Token: p.CLIOptions.Manage.GlobalOptions.ManageToken,
@@ -156,15 +111,6 @@ func (p *Plumber) HandleStopTunnelCmd(ctx context.Context, client protos.Plumber
 }
 
 func (p *Plumber) HandleResumeTunnelCmd(ctx context.Context, client protos.PlumberServerClient) error {
-	p.EnqueueManage(posthog.Capture{
-		Event:      "command_manage",
-		DistinctId: p.PersistentConfig.PlumberID,
-		Properties: map[string]interface{}{
-			"tunnel_id": p.CLIOptions.Manage.Resume.Tunnel.Id,
-			"method":    "resume_tunnel",
-		},
-	})
-
 	resp, err := client.ResumeTunnel(ctx, &protos.ResumeTunnelRequest{
 		Auth: &common.Auth{
 			Token: p.CLIOptions.Manage.GlobalOptions.ManageToken,
