@@ -7,7 +7,6 @@ import (
 	"time"
 
 	"github.com/pkg/errors"
-	"github.com/posthog/posthog-go"
 	"github.com/sirupsen/logrus"
 	"google.golang.org/grpc"
 
@@ -164,19 +163,6 @@ func (p *Plumber) startGRPCServer() error {
 
 	go p.watchServiceShutdown(grpcServer)
 
-	p.Telemetry.Enqueue(posthog.Capture{
-		Event:      "command_server",
-		DistinctId: p.PersistentConfig.ClusterID,
-		Properties: map[string]interface{}{
-			"cluster_id":             p.CLIOptions.Server.ClusterId,
-			"node_id":                p.CLIOptions.Server.NodeId,
-			"use_tls":                p.CLIOptions.Server.UseTls,
-			"enable_cluster":         p.CLIOptions.Server.EnableCluster,
-			"tls_skip_verify":        p.CLIOptions.Server.TlsSkipVerify,
-			"remote_control_enabled": p.CLIOptions.Server.RemoteControlEnabled,
-		},
-	})
-
 	p.log.Debugf("starting gRPC server on %s", p.CLIOptions.Server.GrpcListenAddress)
 
 	errCh := make(chan error, 1)
