@@ -1,10 +1,8 @@
 package plumber
 
 import (
-	"github.com/pkg/errors"
-	"github.com/posthog/posthog-go"
-
 	"github.com/batchcorp/plumber-schemas/build/go/protos/records"
+	"github.com/pkg/errors"
 
 	"github.com/streamdal/plumber/backends"
 	"github.com/streamdal/plumber/options"
@@ -18,14 +16,6 @@ func (p *Plumber) HandleTunnelCmd() error {
 		return errors.Wrap(err, "unable to instantiate backend")
 	}
 
-	p.Telemetry.Enqueue(posthog.Capture{
-		Event:      "command_tunnel",
-		DistinctId: p.PersistentConfig.PlumberID,
-		Properties: map[string]interface{}{
-			"backend": backend.Name(),
-		},
-	})
-
 	// Run up tunnel
 	// Plumber cluster ID purposefully left blank here so the destination becomes ephemeral
 	tunnelSvc, err := tunnel.New(p.CLIOptions.Tunnel, &tunnel.Config{
