@@ -12,7 +12,7 @@ import (
 	"github.com/batchcorp/collector-schemas/build/go/protos/records"
 	"github.com/batchcorp/collector-schemas/build/go/protos/services"
 
-	"github.com/batchcorp/plumber/backends/cdcpostgres/types"
+	"github.com/streamdal/plumber/backends/cdcpostgres/types"
 )
 
 // handleCdcPostgres sends a cdc-postgres relay message to the GRPC server
