@@ -1,10 +1,11 @@
 package server
 
 import (
-	. "github.com/batchcorp/plumber/validate"
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
 
+	. "github.com/streamdal/plumber/validate"
+
 	"github.com/batchcorp/plumber-schemas/build/go/protos/common"
 )
 
